embassy-stm32

Crates

git

Versions

stm32h573ai

Flavors

USB

Struct USB 

pub struct USB { /* private fields */ }
USB peripheral

Implementations

Source

impl USB

pub const unsafe fn steal() -> Peri<'static, Self>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.